@@ -16,7 +16,7 @@ use Term::ANSIColor qw/colored/;
 use File::ShareDir qw/dist_dir/;
 use Path::Tiny;
 
-our $VERSION = "0.004";
+our $VERSION = "0.005";
 
 has [qw/base_url api_key api_pass test/] => (
     is => 'rw',
@@ -59,27 +59,7 @@ sub list {
     my ($self, $opt, $query) = @_;
     my $jenkins = $self->jenkins();
 
-    $self->_action(1, $query, sub {
-        my $name = $_->{name};
-        my $extra = '';
-
-        if ( $_->{color} =~ s/_anime// ) {
-            $extra = '*';
-        }
-
-        if ( $opt->{verbose} ) {
-            eval {
-                my $details = $jenkins->_json_api(['job', $_->{name}, qw/api json/], { extra_params => { depth => 1 } });
-                $extra .= "\t" . localtime( ( $details->{lastBuild}{timestamp} || 0 ) / 1000 );
-            };
-            $name = $self->base_url . 'job/' . $name;
-        }
-
-        # map "jenkins" colours to real colours
-        my $color = $self->colour_map->{$_->{color}} || [$_->{color}];
-
-        print colored($color, $name), " $extra\n";
-    });
+    $self->_action(1, $query, $self->_ls_job($opt, $jenkins));
 
     return;
 }
@@ -204,6 +184,31 @@ sub load {
     return;
 }
 
+sub watch {
+    my ($self, $opt, @jobs) = @_;
+    my $jenkins = $self->jenkins();
+
+    $opt->{sleep} ||= 30;
+    my $query = join '|', @jobs;
+
+    while (1) {
+        my @out;
+        my $ls = $self->_ls_job($opt, $jenkins, 1);
+        print "\n...\n";
+
+        $self->_action(1, $query, sub {
+            push @out, $ls->(@_);
+        });
+
+        print "\e[2J\e[0;0H\e[K";
+        print "Jenkins Jobs: ", (join ', ', @jobs), "\n\n";
+        print sort @out;
+        sleep $opt->{sleep};
+    }
+
+    return;
+}
+
 sub enable {
     my ($self, $opt, $query) = @_;
 
@@ -284,6 +289,37 @@ sub _action {
     return;
 }
 
+sub _ls_job {
+    my ($self, $opt, $jenkins, $return) = @_;
+
+    return sub {
+        my $name = $_->{name};
+        my $extra = '';
+
+        if ( $_->{color} =~ s/_anime// ) {
+            $extra = '*';
+        }
+
+        if ( $opt->{verbose} ) {
+            eval {
+                my $details = $jenkins->_json_api(['job', $_->{name}, qw/api json/], { extra_params => { depth => 1 } });
+                $extra .= "\t" . localtime( ( $details->{lastBuild}{timestamp} || 0 ) / 1000 );
+                $extra .= "\t($details->{lastBuild}{displayName} / $details->{lastBuild}{builtOn})";
+            };
+            $name = $self->base_url . 'job/' . $name;
+        }
+
+        # map "jenkins" colours to real colours
+        my $color = $self->colour_map->{$_->{color}} || [$_->{color}];
+
+        my $out = colored($color, $name) . " $extra\n";
+
+        if ($return) {
+            return $out;
+        }
+        print $out;
+    };
+}
 
 1;
 
@@ -295,7 +331,7 @@ App::JenkinsCli - Command line tool for interacting with Jenkins
 
 =head1 VERSION
 
-This documentation refers to App::JenkinsCli version 0.0.1
+This documentation refers to App::JenkinsCli version 0.005
 
 =head1 SYNOPSIS
 
